"""
db4e/Panes/MonerodRemote.py

    Database 4 Everything
    Author: Nadim-Daniel Ghaznavi 
    Copyright (c) 2024-2025 NadimGhaznavi <https://github.com/NadimGhaznavi/db4e>
    License: GPL 3.0
"""

from textual.containers import Container, Vertical, Horizontal
from textual.widgets import Label, MarkdownViewer, Button, Input

from db4e.Messages.SubmitFormData import SubmitFormData
from db4e.Constants.Fields import (
    COMPONENT_FIELD, DELETE_DEPLOYMENT_FIELD,  DEPLOYMENT_MGR_FIELD, FORM_DATA_FIELD, 
    INSTANCE_FIELD, IP_ADDR_FIELD, MONEROD_FIELD, ORIG_INSTANCE_FIELD, 
    RPC_BIND_PORT_FIELD, TO_MODULE_FIELD, TO_METHOD_FIELD, 
    UPDATE_DEPLOYMENT_FIELD, ZMQ_PUB_PORT_FIELD
)
from db4e.Constants.Labels import (
    DELETE_LABEL, INSTANCE_LABEL, IP_ADDR_LABEL, MONEROD_REMOTE_LABEL, 
    RPC_BIND_PORT_LABEL, UPDATE_LABEL, ZMQ_PUB_PORT_LABEL
)

class MonerodRemote(Container):

    instance_input = Input(id="instance_input", restrict=f"[a-zA-Z0-9_\-]*", compact=True)
    ip_addr_input = Input(id="ip_addr_input", restrict=f"[a-z0-9._\-]*", compact=True)
    rpc_bind_port_input = Input(id="rpc_bind_port_input", restrict=f"[0-9]*", compact=True)
    zmq_pub_port_input = Input(id="zmq_pub_port_input", restrict=f"[0-9]*", compact=True)
    orig_instance_input = Input(id="orig_instance_input", classes="hidden")

    def compose(self):
        # Remote Monero daemon deployment form
        STATIC_CONTENT = f"This screen allows you to view and edit the deployment "
        STATIC_CONTENT += f"settings for the {MONEROD_REMOTE_LABEL} deployment."

        yield Vertical(
            MarkdownViewer(STATIC_CONTENT, show_table_of_contents=False, classes="form_intro"),

            Vertical(
                Horizontal(
                    Label(INSTANCE_LABEL, id="instance_label"),
                    self.instance_input),
                Horizontal(
                    Label(IP_ADDR_LABEL, id="ip_addr_label"),
                    self.ip_addr_input),
                Horizontal(
                    Label(RPC_BIND_PORT_LABEL, id="rpc_bind_port_label"),
                    self.rpc_bind_port_input),
                Horizontal(
                    Label(ZMQ_PUB_PORT_LABEL, id="zmq_pub_port_label"),
                    self.zmq_pub_port_input),
                id="monerod_remote_form"),

            self.orig_instance_input,

            Horizontal(
                Button(label=UPDATE_LABEL, id="update_button"),
                Button(label=DELETE_LABEL, id="delete_button"),
                id="buttons"),

        id="pane")

    def set_data(self, rec):

        self.instance_input.value = rec[INSTANCE_FIELD]
        self.orig_instance_input.value = rec[INSTANCE_FIELD]
        self.ip_addr_input.value = rec[IP_ADDR_FIELD]
        self.rpc_bind_port_input.value = str(rec[RPC_BIND_PORT_FIELD])
        self.zmq_pub_port_input.value = str(rec[ZMQ_PUB_PORT_FIELD])
        
    def on_button_pressed(self, event: Button.Pressed) -> None:
        event.stop()
        button_id = event.button.id
        if button_id == "update_button":
            form_data = {
                COMPONENT_FIELD: MONEROD_FIELD,
                TO_MODULE_FIELD: DEPLOYMENT_MGR_FIELD,
                TO_METHOD_FIELD: UPDATE_DEPLOYMENT_FIELD,
                FORM_DATA_FIELD: True,
                INSTANCE_FIELD: self.query_one("#instance_input", Input).value,
                ORIG_INSTANCE_FIELD: self.query_one("#orig_instance_input", Input).value,
                IP_ADDR_FIELD: self.query_one("#ip_addr_input", Input).value,
                RPC_BIND_PORT_FIELD: self.query_one("#rpc_bind_port_input", Input).value,
                ZMQ_PUB_PORT_FIELD: self.query_one("#zmq_pub_port_input", Input).value,
            }
        else:
            form_data = {
                COMPONENT_FIELD: MONEROD_FIELD,
                TO_MODULE_FIELD: DEPLOYMENT_MGR_FIELD,
                TO_METHOD_FIELD: DELETE_DEPLOYMENT_FIELD,
                COMPONENT_FIELD: MONEROD_FIELD,
                INSTANCE_FIELD: self.query_one("#orig_instance_input", Input).value,
            }
        self.app.post_message(SubmitFormData(self, form_data=form_data))